=== modified file 'drizzled/join.cc'
--- drizzled/join.cc	2011-03-23 12:07:34 +0000
+++ drizzled/join.cc	2011-04-04 22:17:21 +0000
@@ -196,7 +196,7 @@
   having_history(NULL),
   select_options(select_options_arg),
   result(result_arg),
-  lock(session_arg->lock),
+  lock(session_arg->open_tables.lock),
   tmp_join(NULL),
   all_fields(fields_arg),
   error(0),
@@ -286,7 +286,7 @@
   having_history= NULL;
   select_options= select_options_arg;
   result= result_arg;
-  lock= session_arg->lock;
+  lock= session_arg->open_tables.lock;
   tmp_join= NULL;
   all_fields= fields_arg;
   error= 0;
@@ -2037,7 +2037,7 @@
     We are not using tables anymore
     Unlock all tables. We may be in an INSERT .... SELECT statement.
   */
-  if (can_unlock && lock && session->lock &&
+  if (can_unlock && lock && session->open_tables.lock &&
       !(select_options & SELECT_NO_UNLOCK) &&
       !select_lex->subquery_in_having &&
       (select_lex == (session->lex().unit.fake_select_lex ?

=== modified file 'drizzled/locking/global.cc'
--- drizzled/locking/global.cc	2011-03-15 23:07:12 +0000
+++ drizzled/locking/global.cc	2011-04-04 22:17:21 +0000
@@ -193,7 +193,7 @@
 	break;
       }
 
-      if (version != refresh_version)
+      if (open_tables.version != refresh_version)
       {
         /* Clear the lock type of all lock data to avoid reusage. */
         reset_lock_data_and_free(&sql_lock);
@@ -1032,7 +1032,7 @@
                             "Waiting for release of readlock");
 
     while (must_wait(is_not_commit) && not getKilled() &&
-	   (!abort_on_refresh || version == refresh_version))
+	   (!abort_on_refresh || open_tables.version == refresh_version))
     {
       boost_unique_lock_t scoped(LOCK_global_read_lock, boost::adopt_lock_t());
       COND_global_read_lock.wait(scoped);

=== modified file 'drizzled/plugin/schema_engine.cc'
--- drizzled/plugin/schema_engine.cc	2011-03-28 17:36:12 +0000
+++ drizzled/plugin/schema_engine.cc	2011-04-04 22:17:21 +0000
@@ -251,11 +251,11 @@
     {
       // Lets delete the temporary tables first outside of locks.
       identifier::table::vector set_of_identifiers;
-      session.doGetTableIdentifiers(identifier, set_of_identifiers);
+      session.open_tables.doGetTableIdentifiers(identifier, set_of_identifiers);
 
       for (identifier::table::vector::iterator iter= set_of_identifiers.begin(); iter != set_of_identifiers.end(); iter++)
       {
-        if (session.drop_temporary_table(*iter))
+        if (session.open_tables.drop_temporary_table(*iter))
         {
           my_error(ER_TABLE_DROP, *iter);
           error= true;

=== modified file 'drizzled/plugin/storage_engine.cc'
--- drizzled/plugin/storage_engine.cc	2011-03-28 17:36:12 +0000
+++ drizzled/plugin/storage_engine.cc	2011-04-04 22:17:21 +0000
@@ -336,7 +336,7 @@
 {
   if (include_temporary_tables)
   {
-    if (session.doDoesTableExist(identifier))
+    if (session.open_tables.doDoesTableExist(identifier))
       return true;
   }
 
@@ -368,7 +368,7 @@
 
   if (include_temporary_tables)
   {
-    Table *table= session.find_temporary_table(identifier);
+    Table *table= session.open_tables.find_temporary_table(identifier);
     if (table)
     {
       return message::table::shared_ptr(new message::Table(*table->getShare()->getTableMessage()));
@@ -651,7 +651,7 @@
   std::for_each(vector_of_engines.begin(), vector_of_engines.end(),
                 AddTableIdentifier(directory, schema_identifier, set_of_identifiers));
 
-  session.doGetTableIdentifiers(directory, schema_identifier, set_of_identifiers);
+  session.open_tables.doGetTableIdentifiers(directory, schema_identifier, set_of_identifiers);
 }
 
 class DropTable: public std::unary_function<identifier::Table&, bool>

=== modified file 'drizzled/session.cc'
--- drizzled/session.cc	2011-04-03 17:22:54 +0000
+++ drizzled/session.cc	2011-04-04 22:17:21 +0000
@@ -191,6 +191,7 @@
   query_id(0),
   warn_query_id(0),
 	transaction(impl_->transaction),
+  open_tables(*this),
   first_successful_insert_id_in_prev_stmt(0),
   first_successful_insert_id_in_cur_stmt(0),
   limit_found_rows(0),

=== modified file 'drizzled/session.h'
--- drizzled/session.h	2011-03-28 14:49:14 +0000
+++ drizzled/session.h	2011-04-04 22:17:21 +0000
@@ -411,6 +411,7 @@
   ResourceContext& getResourceContext(const plugin::MonitoredInTransaction&, size_t index= 0);
 
   session::Transactions& transaction;
+  Open_tables_state& open_tables;
 
   Field *dup_field;
   sigset_t signals;

=== modified file 'drizzled/sql_base.cc'
--- drizzled/sql_base.cc	2011-04-03 17:22:54 +0000
+++ drizzled/sql_base.cc	2011-04-04 22:17:21 +0000
@@ -301,7 +301,7 @@
       result= session->reopen_tables();
 
       /* Set version for table */
-      for (Table *table= session->open_tables_; table ; table= table->getNext())
+      for (Table *table= session->open_tables.open_tables_; table ; table= table->getNext())
       {
         /*
           Preserve the version (0) of write locked tables so that a impending
@@ -335,16 +335,16 @@
 
   (void)scopedLock;
 
-  table::Concurrent *table= static_cast<table::Concurrent *>(open_tables_);
+  table::Concurrent *table= static_cast<table::Concurrent *>(open_tables.open_tables_);
 
   safe_mutex_assert_owner(table::Cache::singleton().mutex().native_handle());
   assert(table->key_read == 0);
   assert(!table->cursor || table->cursor->inited == Cursor::NONE);
 
-  open_tables_= table->getNext();
+  open_tables.open_tables_= table->getNext();
 
   if (table->needs_reopen_or_name_lock() ||
-      version != refresh_version || !table->db_stat)
+      open_tables.version != refresh_version || !table->db_stat)
   {
     table::remove_table(table);
     found_old_table= true;
@@ -384,7 +384,7 @@
 
   boost_unique_lock_t scoped_lock(table::Cache::singleton().mutex()); /* Close all open tables on Session */
 
-  while (open_tables_)
+  while (open_tables.open_tables_)
   {
     found_old_table|= free_cached_table(scoped_lock);
   }
@@ -675,7 +675,7 @@
     Closing a MERGE child before the parent would be fatal if the
     other thread tries to abort the MERGE lock in between.
   */
-  for (prev= &open_tables_; *prev; )
+  for (prev= &open_tables.open_tables_; *prev; )
   {
     Table *list= *prev;
 
@@ -722,7 +722,7 @@
 {
   if (table->getShare()->getType())
   {
-    close_temporary_table(table);
+    open_tables.close_temporary_table(table);
   }
   else
   {
@@ -852,8 +852,8 @@
     return true;
   }
   (*table)->open_placeholder= true;
-  (*table)->setNext(open_tables_);
-  open_tables_= *table;
+  (*table)->setNext(open_tables.open_tables_);
+  open_tables.open_tables_= *table;
 
   return false;
 }
@@ -922,7 +922,7 @@
     TODO -> move this block into a separate function.
   */
   bool reset= false;
-  for (table= getTemporaryTables(); table ; table=table->getNext())
+  for (table= open_tables.getTemporaryTables(); table ; table=table->getNext())
   {
     if (table->getShare()->getCacheKey() == key)
     {
@@ -960,11 +960,11 @@
 
       Note-> refresh_version is currently changed only during FLUSH TABLES.
     */
-    if (!open_tables_)
+    if (!open_tables.open_tables_)
     {
-      version= refresh_version;
+      open_tables.version= refresh_version;
     }
-    else if ((version != refresh_version) &&
+    else if ((open_tables.version != refresh_version) &&
              ! (flags & DRIZZLE_LOCK_IGNORE_FLUSH))
     {
       /* Someone did a refresh while thread was opening tables */
@@ -1034,7 +1034,7 @@
           if (flags & DRIZZLE_LOCK_IGNORE_FLUSH)
           {
             /* Force close at once after usage */
-            version= table->getShare()->getVersion();
+            open_tables.version= table->getShare()->getVersion();
             continue;
           }
 
@@ -1124,8 +1124,8 @@
               by other trying to take name-lock.
             */
             table->open_placeholder= true;
-            table->setNext(open_tables_);
-            open_tables_= table;
+            table->setNext(open_tables.open_tables_);
+            open_tables.open_tables_= table;
 
             return table ;
           }
@@ -1149,8 +1149,8 @@
 
     if (refresh)
     {
-      table->setNext(open_tables_); /* Link into simple list */
-      open_tables_= table;
+      table->setNext(open_tables.open_tables_); /* Link into simple list */
+      open_tables.open_tables_= table;
     }
     table->reginfo.lock_type= TL_READ; /* Assume read */
 
@@ -1164,7 +1164,7 @@
   }
 
   /* These variables are also set in reopen_table() */
-  table->tablenr= current_tablenr++;
+  table->tablenr= open_tables.current_tablenr++;
   table->used_fields= 0;
   table->const_table= 0;
   table->null_row= false;
@@ -1208,14 +1208,14 @@
 {
   safe_mutex_assert_owner(table::Cache::singleton().mutex().native_handle()); /* Adjust locks at the end of ALTER TABLEL */
 
-  if (lock)
+  if (open_tables.lock)
   {
     /*
       If we are not under LOCK TABLES we should have only one table
       open and locked so it makes sense to remove the lock at once.
     */
-    unlockTables(lock);
-    lock= 0;
+    unlockTables(open_tables.lock);
+    open_tables.lock= 0;
   }
 
   /*
@@ -1223,7 +1223,7 @@
     for target table name if we process ALTER Table ... RENAME.
     So loop below makes sense even if we are not under LOCK TABLES.
   */
-  for (Table *table= open_tables_; table ; table=table->getNext())
+  for (Table *table= open_tables.open_tables_; table ; table=table->getNext())
   {
     if (table->getShare()->getCacheKey() == identifier.getKey())
     {
@@ -1264,7 +1264,7 @@
     DRIZZLE_LOCK_IGNORE_GLOBAL_READ_LOCK |
     DRIZZLE_LOCK_IGNORE_FLUSH;
 
-  if (open_tables_ == NULL)
+  if (open_tables.open_tables_ == NULL)
     return false;
 
   safe_mutex_assert_owner(table::Cache::singleton().mutex().native_handle());
@@ -1275,7 +1275,7 @@
     */
     uint32_t opens= 0;
 
-    for (table= open_tables_; table ; table=table->getNext())
+    for (table= open_tables.open_tables_; table ; table=table->getNext())
     {
       opens++;
     }
@@ -1284,8 +1284,8 @@
 
   tables_ptr =tables;
 
-  prev= &open_tables_;
-  for (table= open_tables_; table ; table=next)
+  prev= &open_tables.open_tables_;
+  for (table= open_tables.open_tables_; table ; table=next)
   {
     next= table->getNext();
 
@@ -1347,7 +1347,7 @@
 {
   bool found= send_refresh;
 
-  Table *table= open_tables_;
+  Table *table= open_tables.open_tables_;
 
   for (; table ; table=table->getNext())
   {
@@ -1442,7 +1442,7 @@
 Table *drop_locked_tables(Session *session, const drizzled::identifier::Table &identifier)
 {
   Table *table,*next,**prev, *found= 0;
-  prev= &session->open_tables_;
+  prev= &session->open_tables.open_tables_;
 
   /*
     Note that we need to hold table::Cache::singleton().mutex() while changing the
@@ -1451,7 +1451,7 @@
     Closing a MERGE child before the parent would be fatal if the
     other thread tries to abort the MERGE lock in between.
   */
-  for (table= session->open_tables_; table ; table=next)
+  for (table= session->open_tables.open_tables_; table ; table=next)
   {
     next=table->getNext();
     if (table->getShare()->getCacheKey() == identifier.getKey())
@@ -1498,7 +1498,7 @@
 void abort_locked_tables(Session *session, const drizzled::identifier::Table &identifier)
 {
   Table *table;
-  for (table= session->open_tables_; table ; table= table->getNext())
+  for (table= session->open_tables.open_tables_; table ; table= table->getNext())
   {
     if (table->getShare()->getCacheKey() == identifier.getKey())
     {
@@ -1547,7 +1547,7 @@
   /* Also used for indicating that prelocking is need */
   bool safe_to_ignore_table;
 
-  current_tablenr= 0;
+  open_tables.current_tablenr= 0;
 restart:
   *counter= 0;
   set_proc_info("Opening tables");
@@ -1674,7 +1674,7 @@
   bool refresh;
 
   set_proc_info("Opening table");
-  current_tablenr= 0;
+  open_tables.current_tablenr= 0;
   while (!(table= openTable(table_list, &refresh)) && refresh) ;
 
   if (table)
@@ -1682,10 +1682,10 @@
     table_list->lock_type= lock_type;
     table_list->table=	   table;
 
-    assert(lock == 0);	// You must lock everything at once
+    assert(open_tables.lock == 0);	// You must lock everything at once
     if ((table->reginfo.lock_type= lock_type) != TL_UNLOCK)
     {
-      if (not (lock= lockTables(&table_list->table, 1, 0)))
+      if (not (open_tables.lock= lockTables(&table_list->table, 1, 0)))
         table= NULL;
     }
   }
@@ -1737,7 +1737,7 @@
   if (tables == NULL)
     return 0;
 
-  assert(session->lock == 0);	// You must lock everything at once
+  assert(session->open_tables.lock == 0);	// You must lock everything at once
   Table **start,**ptr;
   uint32_t lock_flag= DRIZZLE_LOCK_NOTIFY_IF_NEED_REOPEN;
 
@@ -1750,7 +1750,7 @@
       *(ptr++)= table->table;
   }
 
-  if (not (session->lock= session->lockTables(start, (uint32_t) (ptr - start), lock_flag)))
+  if (not (session->open_tables.lock= session->lockTables(start, (uint32_t) (ptr - start), lock_flag)))
   {
     return -1;
   }

=== modified file 'plugin/show_dictionary/show_table_status.cc'
--- plugin/show_dictionary/show_table_status.cc	2011-03-10 11:57:20 +0000
+++ plugin/show_dictionary/show_table_status.cc	2011-04-04 22:17:21 +0000
@@ -70,7 +70,7 @@
       table_list.push_back(iter->second);
     }
 
-    for (drizzled::Table *tmp_table= getSession().getTemporaryTables(); tmp_table; tmp_table= tmp_table->getNext())
+    for (drizzled::Table *tmp_table= getSession().open_tables.getTemporaryTables(); tmp_table; tmp_table= tmp_table->getNext())
     {
       if (tmp_table->getShare())
       {

=== modified file 'plugin/show_dictionary/show_temporary_tables.cc'
--- plugin/show_dictionary/show_temporary_tables.cc	2011-02-17 00:14:13 +0000
+++ plugin/show_dictionary/show_temporary_tables.cc	2011-04-04 22:17:21 +0000
@@ -39,7 +39,7 @@
   show_dictionary::Show::Generator(arg),
   session(getSession())
 {
-  table= session.getTemporaryTables();
+  table= session.open_tables.getTemporaryTables();
 }
 
 bool ShowTemporaryTables::Generator::populate()

